@@ -1,7 +1,14 @@
 from time import time
 from urllib.parse import urlencode
-from typing import Optional, Mapping, Any
+from typing import TypedDict, Optional, Mapping, Union, Any
 
+class FlayyerMeta(TypedDict, total=False):
+    agent: str
+    width: Union[str, int]
+    height: Union[str, int]
+    resolution: Union[str, int]
+    id: Union[str, int]
+    v: Union[str, int]
 
 class Flayyer:
     def __init__(
@@ -12,6 +19,7 @@ class Flayyer:
         version: Optional[int] = None,
         extension: str = "jpeg",
         variables: Optional[Mapping[Any, Any]] = None,
+        meta: Optional[FlayyerMeta] = None
     ):
         self.tenant = tenant
         self.deck = deck
@@ -19,10 +27,16 @@ class Flayyer:
         self.version = version
         self.extension = extension
         self.variables = variables if variables else {}
+        self.meta = meta if meta else {}
 
     def querystring(self) -> str:
         defaults = {
-            "__v": str(int(time())),  # This forces crawlers to refresh the image
+            "__v": self.meta.get("v", str(int(time()))),  # This forces crawlers to refresh the image
+            "__id": self.meta.get("id"),
+            "_w": self.meta.get("width"),
+            "_h": self.meta.get("height"),
+            "_res": self.meta.get("resolution"),
+            "_ua": self.meta.get("agent"),
         }
         return to_query({**defaults, **self.variables})
 
